"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderbookFeed = void 0;
const util_1 = require("./util");
function isOrderbookL2Update(obj) {
    return obj.update !== undefined;
}
function isOrderbookL3Update(obj) {
    return obj.additions !== undefined && obj.removals !== undefined;
}
function isOrderbookL2Checkpoint(obj) {
    return (obj.bids !== undefined &&
        obj.asks !== undefined &&
        obj.bids.every((bid) => bid.length() == 2) &&
        obj.asks.every((ask) => ask.length() == 2));
}
function isOrderbookL3Checkpoint(obj) {
    return (obj.bids !== undefined &&
        obj.asks !== undefined &&
        obj.bids.every((order) => isOrder(order)) &&
        obj.asks.every((order) => isOrder(order)));
}
function isOrder(obj) {
    return (obj.price !== undefined &&
        obj.quantity !== undefined &&
        obj.ownerPubkey !== undefined);
}
class OrderbookFeed extends util_1.ReconnectingWebsocketFeed {
    _subscriptions;
    _onL2Update = null;
    _onL3Update = null;
    _onL2Checkpoint = null;
    _onL3Checkpoint = null;
    constructor(url, options) {
        super(url, options?.reconnectionIntervalMs, options?.reconnectionMaxAttempts);
        this._subscriptions = options?.subscriptions;
        this.onMessage((data) => {
            if (isOrderbookL2Update(data) && this._onL2Update) {
                this._onL2Update(data);
            }
            else if (isOrderbookL3Update(data) && this._onL3Update) {
                this._onL3Update(data);
            }
            else if (isOrderbookL2Checkpoint(data) && this._onL2Checkpoint) {
                this._onL2Checkpoint(data);
            }
            else if (isOrderbookL3Checkpoint(data) && this._onL3Checkpoint) {
                this._onL3Checkpoint(data);
            }
        });
        if (this._subscriptions !== undefined) {
            this.subscribe(this._subscriptions);
        }
    }
    subscribe(subscriptions) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'subscribe',
                ...subscriptions,
            }));
        }
        else {
            console.warn('[OrderbookFeed] attempt to subscribe when not connected');
        }
    }
    unsubscribe(marketId) {
        if (this.connected()) {
            this._socket.send(JSON.stringify({
                command: 'unsubscribe',
                marketId,
            }));
        }
        else {
            console.warn('[OrderbookFeed] attempt to unsubscribe when not connected');
        }
    }
    onL2Update(callback) {
        this._onL2Update = callback;
    }
    onL3Update(callback) {
        this._onL3Update = callback;
    }
    onL2Checkpoint(callback) {
        this._onL2Checkpoint = callback;
    }
    onL3Checkpoint(callback) {
        this._onL3Checkpoint = callback;
    }
}
exports.OrderbookFeed = OrderbookFeed;
