import { ReconnectingWebsocketFeed } from './util';
interface OrderbookFeedOptions {
    subscriptions?: OrderbookFeedSubscribeParams;
    reconnectionIntervalMs?: number;
    reconnectionMaxAttempts?: number;
}
interface OrderbookFeedSubscribeParams {
    marketId?: string;
    marketIds?: string[];
}
interface OrderbookL2Update {
    market: string;
    side: 'bid' | 'ask';
    update: [number, number][];
    slot: number;
    writeVersion: number;
}
interface OrderbookL3Update {
    market: string;
    side: 'bid' | 'ask';
    additions: Order[];
    removals: Order[];
    slot: number;
    writeVersion: number;
}
interface Order {
    price: number;
    quantity: number;
    ownerPubkey: string;
}
interface OrderbookL2Checkpoint {
    market: string;
    side: 'bid' | 'ask';
    bids: [number, number][];
    asks: [number, number][];
    slot: number;
    writeVersion: number;
}
interface OrderbookL3Checkpoint {
    market: string;
    side: 'bid' | 'ask';
    bids: Order[];
    asks: Order[];
    slot: number;
    writeVersion: number;
}
export declare class OrderbookFeed extends ReconnectingWebsocketFeed {
    private _subscriptions?;
    private _onL2Update;
    private _onL3Update;
    private _onL2Checkpoint;
    private _onL3Checkpoint;
    constructor(url: string, options?: OrderbookFeedOptions);
    subscribe(subscriptions: OrderbookFeedSubscribeParams): void;
    unsubscribe(marketId: string): void;
    onL2Update(callback: (update: OrderbookL2Update) => void): void;
    onL3Update(callback: (update: OrderbookL3Update) => void): void;
    onL2Checkpoint(callback: (checkpoint: OrderbookL2Checkpoint) => void): void;
    onL3Checkpoint(callback: (checkpoint: OrderbookL3Checkpoint) => void): void;
}
export {};
//# sourceMappingURL=orderbook.d.ts.map